<?php
// src/Acme/UserBundle/Entity/User.php

namespace Neo\UserBundle\Entity;

use FOS\UserBundle\Model\User as BaseUser;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * @ORM\Entity
 * @ORM\Table(name="User")
 * @ORM\Entity(repositoryClass="Neo\UserBundle\Entity\UuserRepository")
 */
class User extends BaseUser
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected $id;

    /**
     * @ORM\Column(type="string", length=255)
     *
     * @Assert\NotBlank(message="Please enter your email address.", groups={"Registration", "Profile"})
     * @Assert\MaxLength(limit="255", message="The name is too long.", groups={"Registration", "Profile"})
     * @Assert\Email(groups={"Registration"})
     */
    protected $email;

    /**
     * @ORM\Column(type="string", length=255, name="email_canonical", unique=true)
     */
    protected $emailCanonical;

    /**
     * @ORM\Column(type="string", length=255)
     */
    protected $username;

    /**
     * @ORM\Column(type="string", length=255, name="username_canonical", unique=true)
     */
     protected $usernameCanonical;

     /**
     * @ORM\Column(type="string", nullable=true)
     */
     protected $name;

     /**
     * @ORM\Column(type="string", nullable=true)
     */
     protected $telephone;
    
    /**
     * @ORM\Column(type="string", nullable=true)
     */
     protected $professionaltitle;

    /**
     * @ORM\Column(type="boolean")
     */
     protected $enabled;

    /**
     * @ORM\Column(type="string")
     */
     protected $salt;

    /**
     * @ORM\Column(type="string")
     */
     protected $password;

    /**
     * @var string
     * @ORM\Column(name="picturePath", type="string", length=100, nullable=true)
      * @Assert\Image(maxSize="500k")
     */
     protected $picturepath;

    /**
     * @ORM\Column(type="datetime", nullable=true, name="last_login")
     */
     protected $lastLogin;

    /**
     * @ORM\Column(type="boolean")
     */
     protected $locked;

    /**
     * @ORM\Column(type="boolean")
     */
     protected $expired;

    /**
     * @ORM\Column(type="datetime", nullable=true, name="expires_at")
     */
     protected $expiresAt;

    /**
     * @ORM\Column(type="string", nullable=true, name="confirmation_token")
     */
     protected $confirmationToken;

    /**
     * @ORM\Column(type="datetime", nullable=true, name="password_requested_at")
     */
     protected $passwordRequestedAt;

     /**
     * @var string
     *
     * @ORM\Column(name="middleName", type="string", length=45, nullable=true)
     */
    private $middlename;

    /**
     * @var string
     *
     * @ORM\Column(name="firstLastName", type="string", length=45, nullable=true)
     */
    private $firstlastname;

    /**
     * @var string
     *
     * @ORM\Column(name="secondLastName", type="string", length=45, nullable=true)
     */
    private $secondlastname;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dateofbirth", type="date", nullable=true)
     */
    private $dateofbirth;

    /**
     * @ORM\Column(type="boolean", name="credentials_expired")
     */
    protected $credentialsExpired;

    /**
     * @ORM\Column(type="datetime", nullable=true, name="credentials_expired_at")
     */
    protected $credentialsExpiredAt;


    /**
     * @var \Ucountries
     *
     * @ORM\ManyToOne(targetEntity="Ucountries")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="country_id", referencedColumnName="id")
     * })
     */
    private $country;

    /**
     * @var \Ulanguages
     *
     * @ORM\ManyToOne(targetEntity="Ulanguages")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="language_id", referencedColumnName="id")
     * })
     */
    private $language;

    /**
     * @var \Uaddresses
     *
     * @ORM\ManyToOne(targetEntity="Uaddresses",cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="address_id", referencedColumnName="id")
     * })
     */

    private $address;
 
 
    /**
     * @ORM\ManyToMany(targetEntity="Ugroup")
     * @ORM\JoinTable(name="UGroupUser",
     *      joinColumns={@ORM\JoinColumn(name="user_id", referencedColumnName="id")},
     *      inverseJoinColumns={@ORM\JoinColumn(name="group_id", referencedColumnName="id")}
     * )
     */
    protected $groups;


    /**
     * @ORM\ManyToMany(targetEntity="Uenterprises", inversedBy="users")
     * @ORM\JoinTable(name="UUsersEnterprises",
     *      joinColumns={@ORM\JoinColumn(name="user_id", referencedColumnName="id")},
     *      inverseJoinColumns={@ORM\JoinColumn(name="enterprise_id", referencedColumnName="id")}
     * )
     */
    private $enterprises;

    /**
     * @ORM\ManyToMany(targetEntity="Uprojects", inversedBy="users")
     * @ORM\JoinTable(name="UUserProjects",
     *      joinColumns={@ORM\JoinColumn(name="user_id", referencedColumnName="id")},
     *      inverseJoinColumns={@ORM\JoinColumn(name="project_id", referencedColumnName="id")}
     * )
     */
    private $projects;




    public function __construct()
    {
        parent::__construct();    
        $this->groups = new ArrayCollection();
        //$this->user_roles = new ArrayCollection();
    }

    /**
     * @return string
     */
    public function getFirstName()
    {
        return $this->firstName;
    }

    /**
     * @return string
     */
    public function getLastName()
    {
        return $this->lastName;
    }

     /**
     * Sets the first name.
     *
     * @param string $firstname
     *
     * @return User
     */
    public function setFirstName($firstname)
    {
        $this->firstName = $firstname;

        return $this;
    }

         /**
     * Sets the last name.
     *
     * @param string $lastname
     *
     * @return User
     */
    public function setLastName($lastname)
    {
        $this->lastName = $lastname;

        return $this;
    }

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set email
     *
     * @param string $email
     * @return User
     */
    public function setEmail($email)
    {
        $this->email = $email;
    
        return $this;
    }

    /**
     * Get email
     *
     * @return string 
     */
    public function getEmail()
    {
        return $this->email;
    }


    public function setTelephone($telephone)
    {
        $this->telephone = $telephone;
    
        return $this;
    }

    public function getTelephone()
    {
        return $this->telephone;
    }

    public function setProfessionaltitle($professionaltitle)
    {
        $this->professionaltitle = $professionaltitle;
    
        return $this;
    }

    public function getProfessionaltitle()
    {
        return $this->professionaltitle;
    }

    /**
     * Set emailCanonical
     *
     * @param string $emailCanonical
     * @return User
     */
    public function setEmailCanonical($emailCanonical)
    {
        $this->emailCanonical = $emailCanonical;
    
        return $this;
    }

    /**
     * Get emailCanonical
     *
     * @return string 
     */
    public function getEmailCanonical()
    {
        return $this->emailCanonical;
    }

    /**
     * Set username
     *
     * @param string $username
     * @return User
     */
    public function setUsername($username)
    {
        $this->username = $username;
    
        return $this;
    }

    /**
     * Get username
     *
     * @return string 
     */
    public function getUsername()
    {
        return $this->username;
    }

    /**
     * Set usernameCanonical
     *
     * @param string $usernameCanonical
     * @return User
     */
    public function setUsernameCanonical($usernameCanonical)
    {
        $this->usernameCanonical = $usernameCanonical;
    
        return $this;
    }

    /**
     * Get usernameCanonical
     *
     * @return string 
     */
    public function getUsernameCanonical()
    {
        return $this->usernameCanonical;
    }

    /**
     * Set enabled
     *
     * @param boolean $enabled
     * @return User
     */
    public function setEnabled($enabled)
    {
        $this->enabled = $enabled;
    
        return $this;
    }

    /**
     * Get enabled
     *
     * @return boolean 
     */
    public function getEnabled()
    {
        return $this->enabled;
    }

    /**
     * Set salt
     *
     * @param string $salt
     * @return User
     */
    public function setSalt($salt)
    {
        $this->salt = $salt;
    
        return $this;
    }

    /**
     * Get salt
     *
     * @return string 
     */
    public function getSalt()
    {
        return $this->salt;
    }

    /**
     * Set password
     *
     * @param string $password
     * @return User
     */
    public function setPassword($password)
    {
        $this->password = $password;
    
        return $this;
    }

    /**
     * Get password
     *
     * @return string 
     */
    public function getPassword()
    {
        return $this->password;
    }

    /**
     * Set picturepath
     *
     * @param string $picturepath
     * @return User
     */
    public function setPicturepath($picturepath)
    {
        $this->picturepath = $picturepath;
    
        return $this;
    }

    /**
     * Get picturepath
     *
     * @return string 
     */
    public function getPicturepath()
    
{        return $this->picturepath;
    }

    /**
     * Get lastLogin
     *
     * @return \DateTime 
     */
    public function getLastLogin()
    {
        return $this->lastLogin;
    }

    /**
     * Set locked
     *
     * @param boolean $locked
     * @return User
     */
    public function setLocked($locked)
    {
        $this->locked = $locked;
    
        return $this;
    }

    /**
     * Get locked
     *
     * @return boolean 
     */
    public function getLocked()
    {
        return $this->locked;
    }

    /**
     * Get expired
     *
     * @return boolean 
     */
    public function getExpired()
    {
        return $this->expired;
    }


    /**
     * Get expiresAt
     *
     * @return \DateTime 
     */
    public function getExpiresAt()
    {
        return $this->expiresAt;
    }

    /**
     * Set confirmationToken
     *
     * @param string $confirmationToken
     * @return User
     */
    public function setConfirmationToken($confirmationToken)
    {
        $this->confirmationToken = $confirmationToken;
    
        return $this;
    }

    /**
     * Get confirmationToken
     *
     * @return string 
     */
    public function getConfirmationToken()
    {
        return $this->confirmationToken;
    }


    /**
     * Get passwordRequestedAt
     *
     * @return \DateTime 
     */
    public function getPasswordRequestedAt()
    {
        return $this->passwordRequestedAt;
    }

    /**
     * Set credentialsExpired
     *
     * @param boolean $credentialsExpired
     * @return User
     */
    public function setCredentialsExpired($credentialsExpired)
    {
        $this->credentialsExpired = $credentialsExpired;
    
        return $this;
    }

    /**
     * Get credentialsExpired
     *
     * @return boolean 
     */
    public function getCredentialsExpired()
    {
        return $this->credentialsExpired;
    }

    /**
     * Set credentialsExpiredAt
     *
     * @param \DateTime $credentialsExpiredAt
     * @return User
     */
    public function setCredentialsExpiredAt($credentialsExpiredAt)
    {
        $this->credentialsExpiredAt = $credentialsExpiredAt;
    
        return $this;
    }

    /**
     * Get credentialsExpiredAt
     *
     * @return \DateTime 
     */
    public function getCredentialsExpiredAt()
    {
        return $this->credentialsExpiredAt;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return User
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set expired
     *
     * @param boolean $expired
     * @return User
     */
    public function setExpired($expired)
    {
        $this->expired = $expired;
    
        return $this;
    }


    /**
     * Set middlename
     *
     * @param string $middlename
     * @return User
     */
    public function setMiddlename($middlename)
    {
        $this->middlename = $middlename;
    
        return $this;
    }

    /**
     * Get middlename
     *
     * @return string 
     */
    public function getMiddlename()
    {
        return $this->middlename;
    }

    /**
     * Set firstlastname
     *
     * @param string $firstlastname
     * @return User
     */
    public function setFirstlastname($firstlastname)
    {
        $this->firstlastname = $firstlastname;
    
        return $this;
    }

    /**
     * Get firstlastname
     *
     * @return string 
     */
    public function getFirstlastname()
    {
        return $this->firstlastname;
    }

    /**
     * Set secondlastname
     *
     * @param string $secondlastname
     * @return User
     */
    public function setSecondlastname($secondlastname)
    {
        $this->secondlastname = $secondlastname;
    
        return $this;
    }

    /**
     * Get secondlastname
     *
     * @return string 
     */
    public function getSecondlastname()
    {
        return $this->secondlastname;
    }

    /**
     * Set dateofbirth
     *
     * @param \DateTime $dateofbirth
     * @return User
     */
    public function setDateofbirth($dateofbirth)
    {
        $this->dateofbirth = $dateofbirth;
    
        return $this;
    }

    /**
     * Get dateofbirth
     *
     * @return \DateTime 
     */
    public function getDateofbirth()
    {
        return $this->dateofbirth;
    }


    /**
     * Set country
     *
     * @param \Neo\UserBundle\Entity\Ucountries $country
     * @return User
     */
    public function setCountry(\Neo\UserBundle\Entity\Ucountries $country = null)
    {
        $this->country = $country;
    
        return $this;
    }

    /**
     * Get country
     *
     * @return \Neo\UserBundle\Entity\Ucountries 
     */
    public function getCountry()
    {
        return $this->country;
    }

    /**
     * Set language
     *
     * @param \Neo\UserBundle\Entity\Ulanguages $language
     * @return User
     */
    public function setLanguage(\Neo\UserBundle\Entity\Ulanguages $language = null)
    {
        $this->language = $language;
    
        return $this;
    }

    /**
     * Get language
     *
     * @return \Neo\UserBundle\Entity\Ulanguages 
     */
    public function getLanguage()
    {
        return $this->language;
    }

    /**
     * Set address
     *
     * @param \Neo\UserBundle\Entity\Uaddresses $address
     * @return User
     */
    public function setAddress(\Neo\UserBundle\Entity\Uaddresses $address = null)
    {
        $this->address = $address;
    
        return $this;
    }

    /**
     * Get address
     *
    *  @return \Neo\UserBundle\Entity\Uaddresses 
     */
    public function getAddress()
    {
        return $this->address;
    }

    public function __tostring()
    {
        return $this->getUsername();
    }

    public function getRoles()
    {
        return $this->groups->toArray();
    }

    public function setGroups($groups)
    {
        $this->groups[] =$groups;
        return $this;
    }

}